@@ -4,31 +4,32 @@ import copy, types
 from datetime import datetime, date
 from exception import MonSQLException
 
-"""
-TODO: When using Query as source, not defining fields will lead to some problem, try to fix it
-"""
+
 class Query:
-    def __init__(self, source=None, filter=None, fields=None, skip=0, limit=None, sort=None, alias=None):
+    def __init__(self, source=None, filter=None, fields=None, skip=0, limit=None, sort=None, distinct=False, alias=None):
         self.source = source
         self.filter = filter
         self.fields = fields
         self.sort = sort
         self.limit = limit
         self.skip  = skip
+        self.distinct = distinct
         self.alias = alias
 
     def clone(self):
         return Query(source=copy.deepcopy(self.source), 
                  filter=copy.deepcopy(self.filter), 
                  fields=copy.deepcopy(self.fields), 
-                 skip=skip, 
-                 limit=limit,
+                 skip=self.skip, 
+                 limit=self.limit,
                  sort=copy.deepcopy(self.sort),
+                 distinct=self.distinct,
                  alias=copy.deepcopy(self.alias))   
 
     def add_filter(self, obj):
         self.filter = {'$and': [obj, self.filter]}
 
+
 def value_to_sql_str(v):
     if v is None:
         return 'null'
@@ -47,6 +48,7 @@ def value_to_sql_str(v):
 
     return str(v)
 
+
 class QueryCondition:
 
     MYSQL_RESERVE_WORDS                 = (u'index', )
@@ -93,7 +95,7 @@ class QueryCondition:
                     if u'$not' == query_field:
                         not_condition = QueryCondition(query_value).to_sql()
                         if not_condition is not None:
-                            return '!(%s)' %(not_condition)
+                            return 'NOT (%s)' %(not_condition)
                         else:
                             return None
 
